@@ -72,7 +72,7 @@ class PytestMultihostOutput:
         # Use values from provisioning-config mhcfg section - as default values
         # options defined in metadata takes precedence over options in
         # provisioning-config as it is "closer" to user.
-        mhcfg = self._config["mhcfg"] | mhcfg
+        mhcfg = self._config.get("mhcfg", {}) | mhcfg
 
         for domain in mhcfg["domains"]:
             for host in domain["hosts"]:
@@ -108,19 +108,32 @@ class PytestMultihostOutput:
                     if username:
                         host["username"] = username
 
-                if host["group"] == "ad_root":
+                group = host.get("group")
+                if not group:
+                    groups = host.get("groups")
+                    if isinstance(groups, list) and len(groups):
+                        group = groups[0]
+                    else:
+                        group = ""  # group is required, but not part of output
+
+                if group == "ad_root":
                     mhcfg["ad_top_domain"] = domain["name"]
                     mhcfg["ad_hostname"] = host["name"]
                     mhcfg["ad_ip"] = host["ip"]
-                elif host["group"] == "ad_subdomain":
+                elif group == "ad_subdomain":
                     mhcfg["ad_sub_domain"] = domain["name"]
                     mhcfg["ad_sub_hostname"] = host["name"]
                     mhcfg["ad_sub_ip"] = host["ip"]
 
+                host_custom_attrs = host.get("pytest_multihost")
+
                 rm_keys = [key for key in host.keys() if key not in host_allowed_attrs]
                 for key in rm_keys:
                     del host[key]
 
+                if isinstance(host_custom_attrs, dict):
+                    host.update(host_custom_attrs)
+
             domain_rm_keys = [
                 key for key in domain.keys() if key not in ["name", "type", "hosts"]
             ]
