@@ -27,9 +27,9 @@ from xmlrpc.client import Fault
 from bkr.client import BeakerJob, BeakerRecipe, BeakerRecipeSet
 from bkr.common.hub import HubProxy
 from bkr.common.pyconfig import PyConfigParser
+from gssapi.exceptions import MissingCredentialsError
 
-from mrack.context import global_context
-from mrack.errors import ProvisioningError, ValidationError
+from mrack.errors import NotAuthenticatedError, ProvisioningError, ValidationError
 from mrack.host import (
     STATUS_ACTIVE,
     STATUS_DELETED,
@@ -80,7 +80,6 @@ class BeakerProvider(Provider):
         self.dsp_name = "Beaker"
         self.conf = PyConfigParser()
         self.poll_sleep = 45  # seconds
-        self.pubkey = None
         self.max_retry = 1  # for retry strategy
         self.status_map = {
             "Reserved": STATUS_ACTIVE,
@@ -103,7 +102,6 @@ class BeakerProvider(Provider):
         distros,
         timeout,
         reserve_duration,
-        pubkey,
         strategy=STRATEGY_ABORT,
         max_retry=1,
     ):
@@ -114,13 +112,19 @@ class BeakerProvider(Provider):
         self.distros = distros
         self.timeout = timeout
         self.reserve_duration = reserve_duration
-        self.pubkey = pubkey
         login_start = datetime.now()
         default_config = os.path.expanduser(
             os.environ.get("BEAKER_CONF", "/etc/beaker/client.conf")  # TODO use provc
         )  # get the beaker config for initialization of hub
         self.conf.load_from_file(default_config)
-        self.hub = HubProxy(logger=logger, conf=self.conf)
+        try:
+            self.hub = HubProxy(logger=logger, conf=self.conf)
+        except MissingCredentialsError as kinit_err:
+            raise NotAuthenticatedError(
+                f"{self.dsp_name} needs Kerberos ticket to authenticate to BeakerHub. "
+                "Run 'kinit $USER' command to obtain Kerberos credentials."
+            ) from kinit_err
+
         login_end = datetime.now()
         login_duration = login_end - login_start
         logger.info(f"{self.dsp_name} Init duration {login_duration}")
@@ -144,47 +148,10 @@ class BeakerProvider(Provider):
         """Check that hosts can be provisioned."""
         return True
 
-    def _allow_ssh_key(self, pubkey):
-        """Create ssh key content to be injected to xml."""
-        with open(os.path.expanduser(pubkey), "r") as key_file:
-            key_content = key_file.read()
-
-        return [
-            """%%post
-mkdir -p /root/.ssh
-cat >>/root/.ssh/authorized_keys << "__EOF__"
-%s__EOF__
-restorecon -R /root/.ssh
-chmod go-w /root /root/.ssh /root/.ssh/authorized_keys
-%%end"""
-            % "".join(key_content)
-        ]
-
     def _req_to_bkr_job(self, req):  # pylint: disable=too-many-locals
         """Transform requirement to beaker job xml."""
         specs = deepcopy(req)  # work with own copy, do not modify the input
 
-        # Job attributes:
-        specs.update({"retention_tag": "audit"})
-        specs.update({"product": "[internal]"})
-        specs.update({"whiteboard": "This job has been created using mrack."})
-
-        # RecipeSet attributes
-        specs.update({"priority": "Normal"})
-
-        # Add allowed keys
-        specs.update({"ks_append": self._allow_ssh_key(self.pubkey)})
-
-        # Use ks_meta
-        specs.update({"ks_meta": "harness='restraint-rhts beakerlib-redhat'"})
-
-        # Recipe task definition
-        specs.update(
-            {  # we use dummy task because beaker reuire a task in recipe
-                "tasks": [{"name": "/distribution/dummy", "role": "STANDALONE"}]
-            }
-        )
-
         # Create recipe with the specifications
         recipe = BeakerRecipe(**specs)
         recipe.addBaseRequires(**specs)
@@ -195,11 +162,7 @@ chmod go-w /root /root/.ssh /root/.ssh/authorized_keys
         arch_node.setAttribute("value", specs["arch"])
         recipe.addDistroRequires(arch_node)
 
-        host_requires = global_context.PROV_CONFIG[PROVISIONER_KEY].get(
-            "hostRequires",
-            specs.get(f"mrack_{PROVISIONER_KEY}", {}).get("hostRequires", {}),
-        )
-
+        host_requires = specs.get("hostRequires")
         if host_requires:  # suppose to be dict like {"or": [dict()], "and": [dict()]}
             for operand, operand_value in host_requires.items():
                 if operand.startswith("_"):
@@ -218,9 +181,9 @@ chmod go-w /root /root/.ssh /root/.ssh/authorized_keys
                 )
 
         # Specify the custom xml distro_tag node with values from provisioning config
-        distro_tags = global_context.PROV_CONFIG["beaker"].get("distro_tags")
+        distro_tags = specs.get("distro_tags")
         if distro_tags:
-            for tag in distro_tags.get(specs["distro"], []):
+            for tag in distro_tags:
                 tag_node = xml_doc().createElement("distro_tag")
                 tag_node.setAttribute("op", "=")
                 tag_node.setAttribute("value", tag)
@@ -300,7 +263,7 @@ chmod go-w /root /root/.ssh /root/.ssh/authorized_keys
 
         return result
 
-    def _get_recipe_info(self, beaker_id):
+    def _get_recipe_info(self, beaker_id, log_msg_start):
         """Get info about the recipe for beaker job id."""
         bkr_job_xml = self.hub.taskactions.to_xml(beaker_id).encode("utf8")
 
@@ -316,7 +279,12 @@ chmod go-w /root /root/.ssh /root/.ssh/authorized_keys
                 }
             )
 
-        return resources[0] if len(resources) == 1 else []
+        logger.debug(
+            f"{log_msg_start} has status:{resources[0]['status']}, "
+            f"result:{resources[0]['result']}, waiting another {self.poll_sleep:.1f}s"
+        )
+
+        return resources[0]
 
     async def wait_till_provisioned(self, resource):
         """Wait for Beaker provisioning result."""
@@ -331,7 +299,7 @@ chmod go-w /root /root/.ssh /root/.ssh/authorized_keys
         timeout_time = datetime.now() + timedelta(minutes=self.timeout)
 
         while datetime.now() < timeout_time:
-            bkr_res = self._get_recipe_info(beaker_id)
+            bkr_res = self._get_recipe_info(beaker_id, log_msg_start=log_msg_start)
             status = bkr_res["status"]
             job_url = (
                 f"{self.hub._hub_url}"  # pylint: disable=protected-access
@@ -344,11 +312,6 @@ chmod go-w /root /root/.ssh /root/.ssh/authorized_keys
                     f"has changed status ({prev_status} -> {status})"
                 )
                 prev_status = status
-            else:
-                logger.info(
-                    f"{log_msg_start} Job {job_url} has not changed status "
-                    f"({status}), waiting another {self.poll_sleep:.1f}s"
-                )
 
             if self.status_map.get(status) == STATUS_PROVISIONING:
                 await asyncio.sleep(self.poll_sleep)
